@@ -113,11 +113,28 @@
 # undef BSON_HAVE_SYSCALL_TID
 #endif
 
+
+/*
+ * Define to 1 if you have arc4random_buf available on your platform.
+ */
+#define BSON_HAVE_ARC4RANDOM_BUF 0
+#if BSON_HAVE_ARC4RANDOM_BUF != 1
+# undef BSON_HAVE_ARC4RANDOM_BUF
+#endif
+
+
+/*
+ * Define to 1 if you have rand_r available on your platform.
+ */
 #define BSON_HAVE_RAND_R 0
 #if BSON_HAVE_RAND_R != 1
 # undef BSON_HAVE_RAND_R
 #endif
 
+
+/*
+ * Define to 1 if you have strlcpy available on your platform.
+ */
 #define BSON_HAVE_STRLCPY 0
 #if BSON_HAVE_STRLCPY != 1
 # undef BSON_HAVE_STRLCPY
